package App::Nopaste::Service::Shadowcat;
use strict;
use warnings;
use base 'App::Nopaste::Service';

sub uri { "http://paste.scsys.co.uk" }

=head1 NAME

App::Nopaste::Service::Shadowcat - http://paste.scsys.co.uk/

=cut

1;

